/***************************************************************************//**
* \file Debugging_BOOT.h
* \version 4.0
*
* \brief
*  This file provides constants and parameter values of the bootloader
*  communication APIs for the SCB Component.
*
* Note:
*
********************************************************************************
* \copyright
* Copyright 2014-2017, Cypress Semiconductor Corporation. All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_SCB_BOOT_Debugging_H)
#define CY_SCB_BOOT_Debugging_H

#include "Debugging_PVT.h"

#if (Debugging_SCB_MODE_I2C_INC)
    #include "Debugging_I2C.h"
#endif /* (Debugging_SCB_MODE_I2C_INC) */

#if (Debugging_SCB_MODE_EZI2C_INC)
    #include "Debugging_EZI2C.h"
#endif /* (Debugging_SCB_MODE_EZI2C_INC) */

#if (Debugging_SCB_MODE_SPI_INC || Debugging_SCB_MODE_UART_INC)
    #include "Debugging_SPI_UART.h"
#endif /* (Debugging_SCB_MODE_SPI_INC || Debugging_SCB_MODE_UART_INC) */


/***************************************
*  Conditional Compilation Parameters
****************************************/

/* Bootloader communication interface enable */
#define Debugging_BTLDR_COMM_ENABLED ((CYDEV_BOOTLOADER_IO_COMP == CyBtldr_Debugging) || \
                                             (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_Custom_Interface))

/* Enable I2C bootloader communication */
#if (Debugging_SCB_MODE_I2C_INC)
    #define Debugging_I2C_BTLDR_COMM_ENABLED     (Debugging_BTLDR_COMM_ENABLED && \
                                                            (Debugging_SCB_MODE_UNCONFIG_CONST_CFG || \
                                                             Debugging_I2C_SLAVE_CONST))
#else
     #define Debugging_I2C_BTLDR_COMM_ENABLED    (0u)
#endif /* (Debugging_SCB_MODE_I2C_INC) */

/* EZI2C does not support bootloader communication. Provide empty APIs */
#if (Debugging_SCB_MODE_EZI2C_INC)
    #define Debugging_EZI2C_BTLDR_COMM_ENABLED   (Debugging_BTLDR_COMM_ENABLED && \
                                                         Debugging_SCB_MODE_UNCONFIG_CONST_CFG)
#else
    #define Debugging_EZI2C_BTLDR_COMM_ENABLED   (0u)
#endif /* (Debugging_EZI2C_BTLDR_COMM_ENABLED) */

/* Enable SPI bootloader communication */
#if (Debugging_SCB_MODE_SPI_INC)
    #define Debugging_SPI_BTLDR_COMM_ENABLED     (Debugging_BTLDR_COMM_ENABLED && \
                                                            (Debugging_SCB_MODE_UNCONFIG_CONST_CFG || \
                                                             Debugging_SPI_SLAVE_CONST))
#else
        #define Debugging_SPI_BTLDR_COMM_ENABLED (0u)
#endif /* (Debugging_SPI_BTLDR_COMM_ENABLED) */

/* Enable UART bootloader communication */
#if (Debugging_SCB_MODE_UART_INC)
       #define Debugging_UART_BTLDR_COMM_ENABLED    (Debugging_BTLDR_COMM_ENABLED && \
                                                            (Debugging_SCB_MODE_UNCONFIG_CONST_CFG || \
                                                             (Debugging_UART_RX_DIRECTION && \
                                                              Debugging_UART_TX_DIRECTION)))
#else
     #define Debugging_UART_BTLDR_COMM_ENABLED   (0u)
#endif /* (Debugging_UART_BTLDR_COMM_ENABLED) */

/* Enable bootloader communication */
#define Debugging_BTLDR_COMM_MODE_ENABLED    (Debugging_I2C_BTLDR_COMM_ENABLED   || \
                                                     Debugging_SPI_BTLDR_COMM_ENABLED   || \
                                                     Debugging_EZI2C_BTLDR_COMM_ENABLED || \
                                                     Debugging_UART_BTLDR_COMM_ENABLED)


/***************************************
*        Function Prototypes
***************************************/

#if defined(CYDEV_BOOTLOADER_IO_COMP) && (Debugging_I2C_BTLDR_COMM_ENABLED)
    /* I2C Bootloader physical layer functions */
    void Debugging_I2CCyBtldrCommStart(void);
    void Debugging_I2CCyBtldrCommStop (void);
    void Debugging_I2CCyBtldrCommReset(void);
    cystatus Debugging_I2CCyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    cystatus Debugging_I2CCyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);

    /* Map I2C specific bootloader communication APIs to SCB specific APIs */
    #if (Debugging_SCB_MODE_I2C_CONST_CFG)
        #define Debugging_CyBtldrCommStart   Debugging_I2CCyBtldrCommStart
        #define Debugging_CyBtldrCommStop    Debugging_I2CCyBtldrCommStop
        #define Debugging_CyBtldrCommReset   Debugging_I2CCyBtldrCommReset
        #define Debugging_CyBtldrCommRead    Debugging_I2CCyBtldrCommRead
        #define Debugging_CyBtldrCommWrite   Debugging_I2CCyBtldrCommWrite
    #endif /* (Debugging_SCB_MODE_I2C_CONST_CFG) */

#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (Debugging_I2C_BTLDR_COMM_ENABLED) */


#if defined(CYDEV_BOOTLOADER_IO_COMP) && (Debugging_EZI2C_BTLDR_COMM_ENABLED)
    /* Bootloader physical layer functions */
    void Debugging_EzI2CCyBtldrCommStart(void);
    void Debugging_EzI2CCyBtldrCommStop (void);
    void Debugging_EzI2CCyBtldrCommReset(void);
    cystatus Debugging_EzI2CCyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    cystatus Debugging_EzI2CCyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);

    /* Map EZI2C specific bootloader communication APIs to SCB specific APIs */
    #if (Debugging_SCB_MODE_EZI2C_CONST_CFG)
        #define Debugging_CyBtldrCommStart   Debugging_EzI2CCyBtldrCommStart
        #define Debugging_CyBtldrCommStop    Debugging_EzI2CCyBtldrCommStop
        #define Debugging_CyBtldrCommReset   Debugging_EzI2CCyBtldrCommReset
        #define Debugging_CyBtldrCommRead    Debugging_EzI2CCyBtldrCommRead
        #define Debugging_CyBtldrCommWrite   Debugging_EzI2CCyBtldrCommWrite
    #endif /* (Debugging_SCB_MODE_EZI2C_CONST_CFG) */

#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (Debugging_EZI2C_BTLDR_COMM_ENABLED) */

#if defined(CYDEV_BOOTLOADER_IO_COMP) && (Debugging_SPI_BTLDR_COMM_ENABLED)
    /* SPI Bootloader physical layer functions */
    void Debugging_SpiCyBtldrCommStart(void);
    void Debugging_SpiCyBtldrCommStop (void);
    void Debugging_SpiCyBtldrCommReset(void);
    cystatus Debugging_SpiCyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    cystatus Debugging_SpiCyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);

    /* Map SPI specific bootloader communication APIs to SCB specific APIs */
    #if (Debugging_SCB_MODE_SPI_CONST_CFG)
        #define Debugging_CyBtldrCommStart   Debugging_SpiCyBtldrCommStart
        #define Debugging_CyBtldrCommStop    Debugging_SpiCyBtldrCommStop
        #define Debugging_CyBtldrCommReset   Debugging_SpiCyBtldrCommReset
        #define Debugging_CyBtldrCommRead    Debugging_SpiCyBtldrCommRead
        #define Debugging_CyBtldrCommWrite   Debugging_SpiCyBtldrCommWrite
    #endif /* (Debugging_SCB_MODE_SPI_CONST_CFG) */

#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (Debugging_SPI_BTLDR_COMM_ENABLED) */

#if defined(CYDEV_BOOTLOADER_IO_COMP) && (Debugging_UART_BTLDR_COMM_ENABLED)
    /* UART Bootloader physical layer functions */
    void Debugging_UartCyBtldrCommStart(void);
    void Debugging_UartCyBtldrCommStop (void);
    void Debugging_UartCyBtldrCommReset(void);
    cystatus Debugging_UartCyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    cystatus Debugging_UartCyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);

    /* Map UART specific bootloader communication APIs to SCB specific APIs */
    #if (Debugging_SCB_MODE_UART_CONST_CFG)
        #define Debugging_CyBtldrCommStart   Debugging_UartCyBtldrCommStart
        #define Debugging_CyBtldrCommStop    Debugging_UartCyBtldrCommStop
        #define Debugging_CyBtldrCommReset   Debugging_UartCyBtldrCommReset
        #define Debugging_CyBtldrCommRead    Debugging_UartCyBtldrCommRead
        #define Debugging_CyBtldrCommWrite   Debugging_UartCyBtldrCommWrite
    #endif /* (Debugging_SCB_MODE_UART_CONST_CFG) */

#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (Debugging_UART_BTLDR_COMM_ENABLED) */

/**
* \addtogroup group_bootloader
* @{
*/

#if defined(CYDEV_BOOTLOADER_IO_COMP) && (Debugging_BTLDR_COMM_ENABLED)
    #if (Debugging_SCB_MODE_UNCONFIG_CONST_CFG)
        /* Bootloader physical layer functions */
        void Debugging_CyBtldrCommStart(void);
        void Debugging_CyBtldrCommStop (void);
        void Debugging_CyBtldrCommReset(void);
        cystatus Debugging_CyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
        cystatus Debugging_CyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    #endif /* (Debugging_SCB_MODE_UNCONFIG_CONST_CFG) */

    /* Map SCB specific bootloader communication APIs to common APIs */
    #if (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_Debugging)
        #define CyBtldrCommStart    Debugging_CyBtldrCommStart
        #define CyBtldrCommStop     Debugging_CyBtldrCommStop
        #define CyBtldrCommReset    Debugging_CyBtldrCommReset
        #define CyBtldrCommWrite    Debugging_CyBtldrCommWrite
        #define CyBtldrCommRead     Debugging_CyBtldrCommRead
    #endif /* (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_Debugging) */

#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (Debugging_BTLDR_COMM_ENABLED) */

/** @} group_bootloader */

/***************************************
*           API Constants
***************************************/

/* Timeout unit in milliseconds */
#define Debugging_WAIT_1_MS  (1u)

/* Return number of bytes to copy into bootloader buffer */
#define Debugging_BYTES_TO_COPY(actBufSize, bufSize) \
                            ( ((uint32)(actBufSize) < (uint32)(bufSize)) ? \
                                ((uint32) (actBufSize)) : ((uint32) (bufSize)) )

/* Size of Read/Write buffers for I2C bootloader  */
#define Debugging_I2C_BTLDR_SIZEOF_READ_BUFFER   (64u)
#define Debugging_I2C_BTLDR_SIZEOF_WRITE_BUFFER  (64u)

/* Byte to byte time interval: calculated basing on current component
* data rate configuration, can be defined in project if required.
*/
#ifndef Debugging_SPI_BYTE_TO_BYTE
    #define Debugging_SPI_BYTE_TO_BYTE   (160u)
#endif

/* Byte to byte time interval: calculated basing on current component
* baud rate configuration, can be defined in the project if required.
*/
#ifndef Debugging_UART_BYTE_TO_BYTE
    #define Debugging_UART_BYTE_TO_BYTE  (86u)
#endif /* Debugging_UART_BYTE_TO_BYTE */

#endif /* (CY_SCB_BOOT_Debugging_H) */


/* [] END OF FILE */
