/***************************************************************************//**
* \file Debugging_PINS.h
* \version 4.0
*
* \brief
*  This file provides constants and parameter values for the pin components
*  buried into SCB Component.
*
* Note:
*
********************************************************************************
* \copyright
* Copyright 2013-2017, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_SCB_PINS_Debugging_H)
#define CY_SCB_PINS_Debugging_H

#include "cydevice_trm.h"
#include "cyfitter.h"
#include "cytypes.h"


/***************************************
*   Conditional Compilation Parameters
****************************************/

/* Unconfigured pins */
#define Debugging_REMOVE_RX_WAKE_SCL_MOSI_PIN  (1u)
#define Debugging_REMOVE_RX_SCL_MOSI_PIN      (1u)
#define Debugging_REMOVE_TX_SDA_MISO_PIN      (1u)
#define Debugging_REMOVE_CTS_SCLK_PIN      (1u)
#define Debugging_REMOVE_RTS_SS0_PIN      (1u)
#define Debugging_REMOVE_SS1_PIN                 (1u)
#define Debugging_REMOVE_SS2_PIN                 (1u)
#define Debugging_REMOVE_SS3_PIN                 (1u)

/* Mode defined pins */
#define Debugging_REMOVE_I2C_PINS                (1u)
#define Debugging_REMOVE_SPI_MASTER_PINS         (1u)
#define Debugging_REMOVE_SPI_MASTER_SCLK_PIN     (1u)
#define Debugging_REMOVE_SPI_MASTER_MOSI_PIN     (1u)
#define Debugging_REMOVE_SPI_MASTER_MISO_PIN     (1u)
#define Debugging_REMOVE_SPI_MASTER_SS0_PIN      (1u)
#define Debugging_REMOVE_SPI_MASTER_SS1_PIN      (1u)
#define Debugging_REMOVE_SPI_MASTER_SS2_PIN      (1u)
#define Debugging_REMOVE_SPI_MASTER_SS3_PIN      (1u)
#define Debugging_REMOVE_SPI_SLAVE_PINS          (1u)
#define Debugging_REMOVE_SPI_SLAVE_MOSI_PIN      (1u)
#define Debugging_REMOVE_SPI_SLAVE_MISO_PIN      (1u)
#define Debugging_REMOVE_UART_TX_PIN             (0u)
#define Debugging_REMOVE_UART_RX_TX_PIN          (1u)
#define Debugging_REMOVE_UART_RX_PIN             (0u)
#define Debugging_REMOVE_UART_RX_WAKE_PIN        (1u)
#define Debugging_REMOVE_UART_RTS_PIN            (1u)
#define Debugging_REMOVE_UART_CTS_PIN            (1u)

/* Unconfigured pins */
#define Debugging_RX_WAKE_SCL_MOSI_PIN (0u == Debugging_REMOVE_RX_WAKE_SCL_MOSI_PIN)
#define Debugging_RX_SCL_MOSI_PIN     (0u == Debugging_REMOVE_RX_SCL_MOSI_PIN)
#define Debugging_TX_SDA_MISO_PIN     (0u == Debugging_REMOVE_TX_SDA_MISO_PIN)
#define Debugging_CTS_SCLK_PIN     (0u == Debugging_REMOVE_CTS_SCLK_PIN)
#define Debugging_RTS_SS0_PIN     (0u == Debugging_REMOVE_RTS_SS0_PIN)
#define Debugging_SS1_PIN                (0u == Debugging_REMOVE_SS1_PIN)
#define Debugging_SS2_PIN                (0u == Debugging_REMOVE_SS2_PIN)
#define Debugging_SS3_PIN                (0u == Debugging_REMOVE_SS3_PIN)

/* Mode defined pins */
#define Debugging_I2C_PINS               (0u == Debugging_REMOVE_I2C_PINS)
#define Debugging_SPI_MASTER_PINS        (0u == Debugging_REMOVE_SPI_MASTER_PINS)
#define Debugging_SPI_MASTER_SCLK_PIN    (0u == Debugging_REMOVE_SPI_MASTER_SCLK_PIN)
#define Debugging_SPI_MASTER_MOSI_PIN    (0u == Debugging_REMOVE_SPI_MASTER_MOSI_PIN)
#define Debugging_SPI_MASTER_MISO_PIN    (0u == Debugging_REMOVE_SPI_MASTER_MISO_PIN)
#define Debugging_SPI_MASTER_SS0_PIN     (0u == Debugging_REMOVE_SPI_MASTER_SS0_PIN)
#define Debugging_SPI_MASTER_SS1_PIN     (0u == Debugging_REMOVE_SPI_MASTER_SS1_PIN)
#define Debugging_SPI_MASTER_SS2_PIN     (0u == Debugging_REMOVE_SPI_MASTER_SS2_PIN)
#define Debugging_SPI_MASTER_SS3_PIN     (0u == Debugging_REMOVE_SPI_MASTER_SS3_PIN)
#define Debugging_SPI_SLAVE_PINS         (0u == Debugging_REMOVE_SPI_SLAVE_PINS)
#define Debugging_SPI_SLAVE_MOSI_PIN     (0u == Debugging_REMOVE_SPI_SLAVE_MOSI_PIN)
#define Debugging_SPI_SLAVE_MISO_PIN     (0u == Debugging_REMOVE_SPI_SLAVE_MISO_PIN)
#define Debugging_UART_TX_PIN            (0u == Debugging_REMOVE_UART_TX_PIN)
#define Debugging_UART_RX_TX_PIN         (0u == Debugging_REMOVE_UART_RX_TX_PIN)
#define Debugging_UART_RX_PIN            (0u == Debugging_REMOVE_UART_RX_PIN)
#define Debugging_UART_RX_WAKE_PIN       (0u == Debugging_REMOVE_UART_RX_WAKE_PIN)
#define Debugging_UART_RTS_PIN           (0u == Debugging_REMOVE_UART_RTS_PIN)
#define Debugging_UART_CTS_PIN           (0u == Debugging_REMOVE_UART_CTS_PIN)


/***************************************
*             Includes
****************************************/

#if (Debugging_RX_WAKE_SCL_MOSI_PIN)
    #include "Debugging_uart_rx_wake_i2c_scl_spi_mosi.h"
#endif /* (Debugging_RX_SCL_MOSI) */

#if (Debugging_RX_SCL_MOSI_PIN)
    #include "Debugging_uart_rx_i2c_scl_spi_mosi.h"
#endif /* (Debugging_RX_SCL_MOSI) */

#if (Debugging_TX_SDA_MISO_PIN)
    #include "Debugging_uart_tx_i2c_sda_spi_miso.h"
#endif /* (Debugging_TX_SDA_MISO) */

#if (Debugging_CTS_SCLK_PIN)
    #include "Debugging_uart_cts_spi_sclk.h"
#endif /* (Debugging_CTS_SCLK) */

#if (Debugging_RTS_SS0_PIN)
    #include "Debugging_uart_rts_spi_ss0.h"
#endif /* (Debugging_RTS_SS0_PIN) */

#if (Debugging_SS1_PIN)
    #include "Debugging_spi_ss1.h"
#endif /* (Debugging_SS1_PIN) */

#if (Debugging_SS2_PIN)
    #include "Debugging_spi_ss2.h"
#endif /* (Debugging_SS2_PIN) */

#if (Debugging_SS3_PIN)
    #include "Debugging_spi_ss3.h"
#endif /* (Debugging_SS3_PIN) */

#if (Debugging_I2C_PINS)
    #include "Debugging_scl.h"
    #include "Debugging_sda.h"
#endif /* (Debugging_I2C_PINS) */

#if (Debugging_SPI_MASTER_PINS)
#if (Debugging_SPI_MASTER_SCLK_PIN)
    #include "Debugging_sclk_m.h"
#endif /* (Debugging_SPI_MASTER_SCLK_PIN) */

#if (Debugging_SPI_MASTER_MOSI_PIN)
    #include "Debugging_mosi_m.h"
#endif /* (Debugging_SPI_MASTER_MOSI_PIN) */

#if (Debugging_SPI_MASTER_MISO_PIN)
    #include "Debugging_miso_m.h"
#endif /*(Debugging_SPI_MASTER_MISO_PIN) */
#endif /* (Debugging_SPI_MASTER_PINS) */

#if (Debugging_SPI_SLAVE_PINS)
    #include "Debugging_sclk_s.h"
    #include "Debugging_ss_s.h"

#if (Debugging_SPI_SLAVE_MOSI_PIN)
    #include "Debugging_mosi_s.h"
#endif /* (Debugging_SPI_SLAVE_MOSI_PIN) */

#if (Debugging_SPI_SLAVE_MISO_PIN)
    #include "Debugging_miso_s.h"
#endif /*(Debugging_SPI_SLAVE_MISO_PIN) */
#endif /* (Debugging_SPI_SLAVE_PINS) */

#if (Debugging_SPI_MASTER_SS0_PIN)
    #include "Debugging_ss0_m.h"
#endif /* (Debugging_SPI_MASTER_SS0_PIN) */

#if (Debugging_SPI_MASTER_SS1_PIN)
    #include "Debugging_ss1_m.h"
#endif /* (Debugging_SPI_MASTER_SS1_PIN) */

#if (Debugging_SPI_MASTER_SS2_PIN)
    #include "Debugging_ss2_m.h"
#endif /* (Debugging_SPI_MASTER_SS2_PIN) */

#if (Debugging_SPI_MASTER_SS3_PIN)
    #include "Debugging_ss3_m.h"
#endif /* (Debugging_SPI_MASTER_SS3_PIN) */

#if (Debugging_UART_TX_PIN)
    #include "Debugging_tx.h"
#endif /* (Debugging_UART_TX_PIN) */

#if (Debugging_UART_RX_TX_PIN)
    #include "Debugging_rx_tx.h"
#endif /* (Debugging_UART_RX_TX_PIN) */

#if (Debugging_UART_RX_PIN)
    #include "Debugging_rx.h"
#endif /* (Debugging_UART_RX_PIN) */

#if (Debugging_UART_RX_WAKE_PIN)
    #include "Debugging_rx_wake.h"
#endif /* (Debugging_UART_RX_WAKE_PIN) */

#if (Debugging_UART_RTS_PIN)
    #include "Debugging_rts.h"
#endif /* (Debugging_UART_RTS_PIN) */

#if (Debugging_UART_CTS_PIN)
    #include "Debugging_cts.h"
#endif /* (Debugging_UART_CTS_PIN) */


/***************************************
*              Registers
***************************************/

#if (Debugging_RX_SCL_MOSI_PIN)
    #define Debugging_RX_SCL_MOSI_HSIOM_REG   (*(reg32 *) Debugging_uart_rx_i2c_scl_spi_mosi__0__HSIOM)
    #define Debugging_RX_SCL_MOSI_HSIOM_PTR   ( (reg32 *) Debugging_uart_rx_i2c_scl_spi_mosi__0__HSIOM)
    
    #define Debugging_RX_SCL_MOSI_HSIOM_MASK      (Debugging_uart_rx_i2c_scl_spi_mosi__0__HSIOM_MASK)
    #define Debugging_RX_SCL_MOSI_HSIOM_POS       (Debugging_uart_rx_i2c_scl_spi_mosi__0__HSIOM_SHIFT)
    #define Debugging_RX_SCL_MOSI_HSIOM_SEL_GPIO  (Debugging_uart_rx_i2c_scl_spi_mosi__0__HSIOM_GPIO)
    #define Debugging_RX_SCL_MOSI_HSIOM_SEL_I2C   (Debugging_uart_rx_i2c_scl_spi_mosi__0__HSIOM_I2C)
    #define Debugging_RX_SCL_MOSI_HSIOM_SEL_SPI   (Debugging_uart_rx_i2c_scl_spi_mosi__0__HSIOM_SPI)
    #define Debugging_RX_SCL_MOSI_HSIOM_SEL_UART  (Debugging_uart_rx_i2c_scl_spi_mosi__0__HSIOM_UART)
    
#elif (Debugging_RX_WAKE_SCL_MOSI_PIN)
    #define Debugging_RX_WAKE_SCL_MOSI_HSIOM_REG   (*(reg32 *) Debugging_uart_rx_wake_i2c_scl_spi_mosi__0__HSIOM)
    #define Debugging_RX_WAKE_SCL_MOSI_HSIOM_PTR   ( (reg32 *) Debugging_uart_rx_wake_i2c_scl_spi_mosi__0__HSIOM)
    
    #define Debugging_RX_WAKE_SCL_MOSI_HSIOM_MASK      (Debugging_uart_rx_wake_i2c_scl_spi_mosi__0__HSIOM_MASK)
    #define Debugging_RX_WAKE_SCL_MOSI_HSIOM_POS       (Debugging_uart_rx_wake_i2c_scl_spi_mosi__0__HSIOM_SHIFT)
    #define Debugging_RX_WAKE_SCL_MOSI_HSIOM_SEL_GPIO  (Debugging_uart_rx_wake_i2c_scl_spi_mosi__0__HSIOM_GPIO)
    #define Debugging_RX_WAKE_SCL_MOSI_HSIOM_SEL_I2C   (Debugging_uart_rx_wake_i2c_scl_spi_mosi__0__HSIOM_I2C)
    #define Debugging_RX_WAKE_SCL_MOSI_HSIOM_SEL_SPI   (Debugging_uart_rx_wake_i2c_scl_spi_mosi__0__HSIOM_SPI)
    #define Debugging_RX_WAKE_SCL_MOSI_HSIOM_SEL_UART  (Debugging_uart_rx_wake_i2c_scl_spi_mosi__0__HSIOM_UART)    
   
    #define Debugging_RX_WAKE_SCL_MOSI_INTCFG_REG (*(reg32 *) Debugging_uart_rx_wake_i2c_scl_spi_mosi__0__INTCFG)
    #define Debugging_RX_WAKE_SCL_MOSI_INTCFG_PTR ( (reg32 *) Debugging_uart_rx_wake_i2c_scl_spi_mosi__0__INTCFG)
    #define Debugging_RX_WAKE_SCL_MOSI_INTCFG_TYPE_POS  (Debugging_uart_rx_wake_i2c_scl_spi_mosi__SHIFT)
    #define Debugging_RX_WAKE_SCL_MOSI_INTCFG_TYPE_MASK ((uint32) Debugging_INTCFG_TYPE_MASK << \
                                                                           Debugging_RX_WAKE_SCL_MOSI_INTCFG_TYPE_POS)
#else
    /* None of pins Debugging_RX_SCL_MOSI_PIN or Debugging_RX_WAKE_SCL_MOSI_PIN present.*/
#endif /* (Debugging_RX_SCL_MOSI_PIN) */

#if (Debugging_TX_SDA_MISO_PIN)
    #define Debugging_TX_SDA_MISO_HSIOM_REG   (*(reg32 *) Debugging_uart_tx_i2c_sda_spi_miso__0__HSIOM)
    #define Debugging_TX_SDA_MISO_HSIOM_PTR   ( (reg32 *) Debugging_uart_tx_i2c_sda_spi_miso__0__HSIOM)
    
    #define Debugging_TX_SDA_MISO_HSIOM_MASK      (Debugging_uart_tx_i2c_sda_spi_miso__0__HSIOM_MASK)
    #define Debugging_TX_SDA_MISO_HSIOM_POS       (Debugging_uart_tx_i2c_sda_spi_miso__0__HSIOM_SHIFT)
    #define Debugging_TX_SDA_MISO_HSIOM_SEL_GPIO  (Debugging_uart_tx_i2c_sda_spi_miso__0__HSIOM_GPIO)
    #define Debugging_TX_SDA_MISO_HSIOM_SEL_I2C   (Debugging_uart_tx_i2c_sda_spi_miso__0__HSIOM_I2C)
    #define Debugging_TX_SDA_MISO_HSIOM_SEL_SPI   (Debugging_uart_tx_i2c_sda_spi_miso__0__HSIOM_SPI)
    #define Debugging_TX_SDA_MISO_HSIOM_SEL_UART  (Debugging_uart_tx_i2c_sda_spi_miso__0__HSIOM_UART)
#endif /* (Debugging_TX_SDA_MISO_PIN) */

#if (Debugging_CTS_SCLK_PIN)
    #define Debugging_CTS_SCLK_HSIOM_REG   (*(reg32 *) Debugging_uart_cts_spi_sclk__0__HSIOM)
    #define Debugging_CTS_SCLK_HSIOM_PTR   ( (reg32 *) Debugging_uart_cts_spi_sclk__0__HSIOM)
    
    #define Debugging_CTS_SCLK_HSIOM_MASK      (Debugging_uart_cts_spi_sclk__0__HSIOM_MASK)
    #define Debugging_CTS_SCLK_HSIOM_POS       (Debugging_uart_cts_spi_sclk__0__HSIOM_SHIFT)
    #define Debugging_CTS_SCLK_HSIOM_SEL_GPIO  (Debugging_uart_cts_spi_sclk__0__HSIOM_GPIO)
    #define Debugging_CTS_SCLK_HSIOM_SEL_I2C   (Debugging_uart_cts_spi_sclk__0__HSIOM_I2C)
    #define Debugging_CTS_SCLK_HSIOM_SEL_SPI   (Debugging_uart_cts_spi_sclk__0__HSIOM_SPI)
    #define Debugging_CTS_SCLK_HSIOM_SEL_UART  (Debugging_uart_cts_spi_sclk__0__HSIOM_UART)
#endif /* (Debugging_CTS_SCLK_PIN) */

#if (Debugging_RTS_SS0_PIN)
    #define Debugging_RTS_SS0_HSIOM_REG   (*(reg32 *) Debugging_uart_rts_spi_ss0__0__HSIOM)
    #define Debugging_RTS_SS0_HSIOM_PTR   ( (reg32 *) Debugging_uart_rts_spi_ss0__0__HSIOM)
    
    #define Debugging_RTS_SS0_HSIOM_MASK      (Debugging_uart_rts_spi_ss0__0__HSIOM_MASK)
    #define Debugging_RTS_SS0_HSIOM_POS       (Debugging_uart_rts_spi_ss0__0__HSIOM_SHIFT)
    #define Debugging_RTS_SS0_HSIOM_SEL_GPIO  (Debugging_uart_rts_spi_ss0__0__HSIOM_GPIO)
    #define Debugging_RTS_SS0_HSIOM_SEL_I2C   (Debugging_uart_rts_spi_ss0__0__HSIOM_I2C)
    #define Debugging_RTS_SS0_HSIOM_SEL_SPI   (Debugging_uart_rts_spi_ss0__0__HSIOM_SPI)
#if !(Debugging_CY_SCBIP_V0 || Debugging_CY_SCBIP_V1)
    #define Debugging_RTS_SS0_HSIOM_SEL_UART  (Debugging_uart_rts_spi_ss0__0__HSIOM_UART)
#endif /* !(Debugging_CY_SCBIP_V0 || Debugging_CY_SCBIP_V1) */
#endif /* (Debugging_RTS_SS0_PIN) */

#if (Debugging_SS1_PIN)
    #define Debugging_SS1_HSIOM_REG  (*(reg32 *) Debugging_spi_ss1__0__HSIOM)
    #define Debugging_SS1_HSIOM_PTR  ( (reg32 *) Debugging_spi_ss1__0__HSIOM)
    
    #define Debugging_SS1_HSIOM_MASK     (Debugging_spi_ss1__0__HSIOM_MASK)
    #define Debugging_SS1_HSIOM_POS      (Debugging_spi_ss1__0__HSIOM_SHIFT)
    #define Debugging_SS1_HSIOM_SEL_GPIO (Debugging_spi_ss1__0__HSIOM_GPIO)
    #define Debugging_SS1_HSIOM_SEL_I2C  (Debugging_spi_ss1__0__HSIOM_I2C)
    #define Debugging_SS1_HSIOM_SEL_SPI  (Debugging_spi_ss1__0__HSIOM_SPI)
#endif /* (Debugging_SS1_PIN) */

#if (Debugging_SS2_PIN)
    #define Debugging_SS2_HSIOM_REG     (*(reg32 *) Debugging_spi_ss2__0__HSIOM)
    #define Debugging_SS2_HSIOM_PTR     ( (reg32 *) Debugging_spi_ss2__0__HSIOM)
    
    #define Debugging_SS2_HSIOM_MASK     (Debugging_spi_ss2__0__HSIOM_MASK)
    #define Debugging_SS2_HSIOM_POS      (Debugging_spi_ss2__0__HSIOM_SHIFT)
    #define Debugging_SS2_HSIOM_SEL_GPIO (Debugging_spi_ss2__0__HSIOM_GPIO)
    #define Debugging_SS2_HSIOM_SEL_I2C  (Debugging_spi_ss2__0__HSIOM_I2C)
    #define Debugging_SS2_HSIOM_SEL_SPI  (Debugging_spi_ss2__0__HSIOM_SPI)
#endif /* (Debugging_SS2_PIN) */

#if (Debugging_SS3_PIN)
    #define Debugging_SS3_HSIOM_REG     (*(reg32 *) Debugging_spi_ss3__0__HSIOM)
    #define Debugging_SS3_HSIOM_PTR     ( (reg32 *) Debugging_spi_ss3__0__HSIOM)
    
    #define Debugging_SS3_HSIOM_MASK     (Debugging_spi_ss3__0__HSIOM_MASK)
    #define Debugging_SS3_HSIOM_POS      (Debugging_spi_ss3__0__HSIOM_SHIFT)
    #define Debugging_SS3_HSIOM_SEL_GPIO (Debugging_spi_ss3__0__HSIOM_GPIO)
    #define Debugging_SS3_HSIOM_SEL_I2C  (Debugging_spi_ss3__0__HSIOM_I2C)
    #define Debugging_SS3_HSIOM_SEL_SPI  (Debugging_spi_ss3__0__HSIOM_SPI)
#endif /* (Debugging_SS3_PIN) */

#if (Debugging_I2C_PINS)
    #define Debugging_SCL_HSIOM_REG  (*(reg32 *) Debugging_scl__0__HSIOM)
    #define Debugging_SCL_HSIOM_PTR  ( (reg32 *) Debugging_scl__0__HSIOM)
    
    #define Debugging_SCL_HSIOM_MASK     (Debugging_scl__0__HSIOM_MASK)
    #define Debugging_SCL_HSIOM_POS      (Debugging_scl__0__HSIOM_SHIFT)
    #define Debugging_SCL_HSIOM_SEL_GPIO (Debugging_sda__0__HSIOM_GPIO)
    #define Debugging_SCL_HSIOM_SEL_I2C  (Debugging_sda__0__HSIOM_I2C)
    
    #define Debugging_SDA_HSIOM_REG  (*(reg32 *) Debugging_sda__0__HSIOM)
    #define Debugging_SDA_HSIOM_PTR  ( (reg32 *) Debugging_sda__0__HSIOM)
    
    #define Debugging_SDA_HSIOM_MASK     (Debugging_sda__0__HSIOM_MASK)
    #define Debugging_SDA_HSIOM_POS      (Debugging_sda__0__HSIOM_SHIFT)
    #define Debugging_SDA_HSIOM_SEL_GPIO (Debugging_sda__0__HSIOM_GPIO)
    #define Debugging_SDA_HSIOM_SEL_I2C  (Debugging_sda__0__HSIOM_I2C)
#endif /* (Debugging_I2C_PINS) */

#if (Debugging_SPI_SLAVE_PINS)
    #define Debugging_SCLK_S_HSIOM_REG   (*(reg32 *) Debugging_sclk_s__0__HSIOM)
    #define Debugging_SCLK_S_HSIOM_PTR   ( (reg32 *) Debugging_sclk_s__0__HSIOM)
    
    #define Debugging_SCLK_S_HSIOM_MASK      (Debugging_sclk_s__0__HSIOM_MASK)
    #define Debugging_SCLK_S_HSIOM_POS       (Debugging_sclk_s__0__HSIOM_SHIFT)
    #define Debugging_SCLK_S_HSIOM_SEL_GPIO  (Debugging_sclk_s__0__HSIOM_GPIO)
    #define Debugging_SCLK_S_HSIOM_SEL_SPI   (Debugging_sclk_s__0__HSIOM_SPI)
    
    #define Debugging_SS0_S_HSIOM_REG    (*(reg32 *) Debugging_ss0_s__0__HSIOM)
    #define Debugging_SS0_S_HSIOM_PTR    ( (reg32 *) Debugging_ss0_s__0__HSIOM)
    
    #define Debugging_SS0_S_HSIOM_MASK       (Debugging_ss0_s__0__HSIOM_MASK)
    #define Debugging_SS0_S_HSIOM_POS        (Debugging_ss0_s__0__HSIOM_SHIFT)
    #define Debugging_SS0_S_HSIOM_SEL_GPIO   (Debugging_ss0_s__0__HSIOM_GPIO)  
    #define Debugging_SS0_S_HSIOM_SEL_SPI    (Debugging_ss0_s__0__HSIOM_SPI)
#endif /* (Debugging_SPI_SLAVE_PINS) */

#if (Debugging_SPI_SLAVE_MOSI_PIN)
    #define Debugging_MOSI_S_HSIOM_REG   (*(reg32 *) Debugging_mosi_s__0__HSIOM)
    #define Debugging_MOSI_S_HSIOM_PTR   ( (reg32 *) Debugging_mosi_s__0__HSIOM)
    
    #define Debugging_MOSI_S_HSIOM_MASK      (Debugging_mosi_s__0__HSIOM_MASK)
    #define Debugging_MOSI_S_HSIOM_POS       (Debugging_mosi_s__0__HSIOM_SHIFT)
    #define Debugging_MOSI_S_HSIOM_SEL_GPIO  (Debugging_mosi_s__0__HSIOM_GPIO)
    #define Debugging_MOSI_S_HSIOM_SEL_SPI   (Debugging_mosi_s__0__HSIOM_SPI)
#endif /* (Debugging_SPI_SLAVE_MOSI_PIN) */

#if (Debugging_SPI_SLAVE_MISO_PIN)
    #define Debugging_MISO_S_HSIOM_REG   (*(reg32 *) Debugging_miso_s__0__HSIOM)
    #define Debugging_MISO_S_HSIOM_PTR   ( (reg32 *) Debugging_miso_s__0__HSIOM)
    
    #define Debugging_MISO_S_HSIOM_MASK      (Debugging_miso_s__0__HSIOM_MASK)
    #define Debugging_MISO_S_HSIOM_POS       (Debugging_miso_s__0__HSIOM_SHIFT)
    #define Debugging_MISO_S_HSIOM_SEL_GPIO  (Debugging_miso_s__0__HSIOM_GPIO)
    #define Debugging_MISO_S_HSIOM_SEL_SPI   (Debugging_miso_s__0__HSIOM_SPI)
#endif /* (Debugging_SPI_SLAVE_MISO_PIN) */

#if (Debugging_SPI_MASTER_MISO_PIN)
    #define Debugging_MISO_M_HSIOM_REG   (*(reg32 *) Debugging_miso_m__0__HSIOM)
    #define Debugging_MISO_M_HSIOM_PTR   ( (reg32 *) Debugging_miso_m__0__HSIOM)
    
    #define Debugging_MISO_M_HSIOM_MASK      (Debugging_miso_m__0__HSIOM_MASK)
    #define Debugging_MISO_M_HSIOM_POS       (Debugging_miso_m__0__HSIOM_SHIFT)
    #define Debugging_MISO_M_HSIOM_SEL_GPIO  (Debugging_miso_m__0__HSIOM_GPIO)
    #define Debugging_MISO_M_HSIOM_SEL_SPI   (Debugging_miso_m__0__HSIOM_SPI)
#endif /* (Debugging_SPI_MASTER_MISO_PIN) */

#if (Debugging_SPI_MASTER_MOSI_PIN)
    #define Debugging_MOSI_M_HSIOM_REG   (*(reg32 *) Debugging_mosi_m__0__HSIOM)
    #define Debugging_MOSI_M_HSIOM_PTR   ( (reg32 *) Debugging_mosi_m__0__HSIOM)
    
    #define Debugging_MOSI_M_HSIOM_MASK      (Debugging_mosi_m__0__HSIOM_MASK)
    #define Debugging_MOSI_M_HSIOM_POS       (Debugging_mosi_m__0__HSIOM_SHIFT)
    #define Debugging_MOSI_M_HSIOM_SEL_GPIO  (Debugging_mosi_m__0__HSIOM_GPIO)
    #define Debugging_MOSI_M_HSIOM_SEL_SPI   (Debugging_mosi_m__0__HSIOM_SPI)
#endif /* (Debugging_SPI_MASTER_MOSI_PIN) */

#if (Debugging_SPI_MASTER_SCLK_PIN)
    #define Debugging_SCLK_M_HSIOM_REG   (*(reg32 *) Debugging_sclk_m__0__HSIOM)
    #define Debugging_SCLK_M_HSIOM_PTR   ( (reg32 *) Debugging_sclk_m__0__HSIOM)
    
    #define Debugging_SCLK_M_HSIOM_MASK      (Debugging_sclk_m__0__HSIOM_MASK)
    #define Debugging_SCLK_M_HSIOM_POS       (Debugging_sclk_m__0__HSIOM_SHIFT)
    #define Debugging_SCLK_M_HSIOM_SEL_GPIO  (Debugging_sclk_m__0__HSIOM_GPIO)
    #define Debugging_SCLK_M_HSIOM_SEL_SPI   (Debugging_sclk_m__0__HSIOM_SPI)
#endif /* (Debugging_SPI_MASTER_SCLK_PIN) */

#if (Debugging_SPI_MASTER_SS0_PIN)
    #define Debugging_SS0_M_HSIOM_REG    (*(reg32 *) Debugging_ss0_m__0__HSIOM)
    #define Debugging_SS0_M_HSIOM_PTR    ( (reg32 *) Debugging_ss0_m__0__HSIOM)
    
    #define Debugging_SS0_M_HSIOM_MASK       (Debugging_ss0_m__0__HSIOM_MASK)
    #define Debugging_SS0_M_HSIOM_POS        (Debugging_ss0_m__0__HSIOM_SHIFT)
    #define Debugging_SS0_M_HSIOM_SEL_GPIO   (Debugging_ss0_m__0__HSIOM_GPIO)
    #define Debugging_SS0_M_HSIOM_SEL_SPI    (Debugging_ss0_m__0__HSIOM_SPI)
#endif /* (Debugging_SPI_MASTER_SS0_PIN) */

#if (Debugging_SPI_MASTER_SS1_PIN)
    #define Debugging_SS1_M_HSIOM_REG    (*(reg32 *) Debugging_ss1_m__0__HSIOM)
    #define Debugging_SS1_M_HSIOM_PTR    ( (reg32 *) Debugging_ss1_m__0__HSIOM)
    
    #define Debugging_SS1_M_HSIOM_MASK       (Debugging_ss1_m__0__HSIOM_MASK)
    #define Debugging_SS1_M_HSIOM_POS        (Debugging_ss1_m__0__HSIOM_SHIFT)
    #define Debugging_SS1_M_HSIOM_SEL_GPIO   (Debugging_ss1_m__0__HSIOM_GPIO)
    #define Debugging_SS1_M_HSIOM_SEL_SPI    (Debugging_ss1_m__0__HSIOM_SPI)
#endif /* (Debugging_SPI_MASTER_SS1_PIN) */

#if (Debugging_SPI_MASTER_SS2_PIN)
    #define Debugging_SS2_M_HSIOM_REG    (*(reg32 *) Debugging_ss2_m__0__HSIOM)
    #define Debugging_SS2_M_HSIOM_PTR    ( (reg32 *) Debugging_ss2_m__0__HSIOM)
    
    #define Debugging_SS2_M_HSIOM_MASK       (Debugging_ss2_m__0__HSIOM_MASK)
    #define Debugging_SS2_M_HSIOM_POS        (Debugging_ss2_m__0__HSIOM_SHIFT)
    #define Debugging_SS2_M_HSIOM_SEL_GPIO   (Debugging_ss2_m__0__HSIOM_GPIO)
    #define Debugging_SS2_M_HSIOM_SEL_SPI    (Debugging_ss2_m__0__HSIOM_SPI)
#endif /* (Debugging_SPI_MASTER_SS2_PIN) */

#if (Debugging_SPI_MASTER_SS3_PIN)
    #define Debugging_SS3_M_HSIOM_REG    (*(reg32 *) Debugging_ss3_m__0__HSIOM)
    #define Debugging_SS3_M_HSIOM_PTR    ( (reg32 *) Debugging_ss3_m__0__HSIOM)
    
    #define Debugging_SS3_M_HSIOM_MASK      (Debugging_ss3_m__0__HSIOM_MASK)
    #define Debugging_SS3_M_HSIOM_POS       (Debugging_ss3_m__0__HSIOM_SHIFT)
    #define Debugging_SS3_M_HSIOM_SEL_GPIO  (Debugging_ss3_m__0__HSIOM_GPIO)
    #define Debugging_SS3_M_HSIOM_SEL_SPI   (Debugging_ss3_m__0__HSIOM_SPI)
#endif /* (Debugging_SPI_MASTER_SS3_PIN) */

#if (Debugging_UART_RX_PIN)
    #define Debugging_RX_HSIOM_REG   (*(reg32 *) Debugging_rx__0__HSIOM)
    #define Debugging_RX_HSIOM_PTR   ( (reg32 *) Debugging_rx__0__HSIOM)
    
    #define Debugging_RX_HSIOM_MASK      (Debugging_rx__0__HSIOM_MASK)
    #define Debugging_RX_HSIOM_POS       (Debugging_rx__0__HSIOM_SHIFT)
    #define Debugging_RX_HSIOM_SEL_GPIO  (Debugging_rx__0__HSIOM_GPIO)
    #define Debugging_RX_HSIOM_SEL_UART  (Debugging_rx__0__HSIOM_UART)
#endif /* (Debugging_UART_RX_PIN) */

#if (Debugging_UART_RX_WAKE_PIN)
    #define Debugging_RX_WAKE_HSIOM_REG   (*(reg32 *) Debugging_rx_wake__0__HSIOM)
    #define Debugging_RX_WAKE_HSIOM_PTR   ( (reg32 *) Debugging_rx_wake__0__HSIOM)
    
    #define Debugging_RX_WAKE_HSIOM_MASK      (Debugging_rx_wake__0__HSIOM_MASK)
    #define Debugging_RX_WAKE_HSIOM_POS       (Debugging_rx_wake__0__HSIOM_SHIFT)
    #define Debugging_RX_WAKE_HSIOM_SEL_GPIO  (Debugging_rx_wake__0__HSIOM_GPIO)
    #define Debugging_RX_WAKE_HSIOM_SEL_UART  (Debugging_rx_wake__0__HSIOM_UART)
#endif /* (Debugging_UART_WAKE_RX_PIN) */

#if (Debugging_UART_CTS_PIN)
    #define Debugging_CTS_HSIOM_REG   (*(reg32 *) Debugging_cts__0__HSIOM)
    #define Debugging_CTS_HSIOM_PTR   ( (reg32 *) Debugging_cts__0__HSIOM)
    
    #define Debugging_CTS_HSIOM_MASK      (Debugging_cts__0__HSIOM_MASK)
    #define Debugging_CTS_HSIOM_POS       (Debugging_cts__0__HSIOM_SHIFT)
    #define Debugging_CTS_HSIOM_SEL_GPIO  (Debugging_cts__0__HSIOM_GPIO)
    #define Debugging_CTS_HSIOM_SEL_UART  (Debugging_cts__0__HSIOM_UART)
#endif /* (Debugging_UART_CTS_PIN) */

#if (Debugging_UART_TX_PIN)
    #define Debugging_TX_HSIOM_REG   (*(reg32 *) Debugging_tx__0__HSIOM)
    #define Debugging_TX_HSIOM_PTR   ( (reg32 *) Debugging_tx__0__HSIOM)
    
    #define Debugging_TX_HSIOM_MASK      (Debugging_tx__0__HSIOM_MASK)
    #define Debugging_TX_HSIOM_POS       (Debugging_tx__0__HSIOM_SHIFT)
    #define Debugging_TX_HSIOM_SEL_GPIO  (Debugging_tx__0__HSIOM_GPIO)
    #define Debugging_TX_HSIOM_SEL_UART  (Debugging_tx__0__HSIOM_UART)
#endif /* (Debugging_UART_TX_PIN) */

#if (Debugging_UART_RX_TX_PIN)
    #define Debugging_RX_TX_HSIOM_REG   (*(reg32 *) Debugging_rx_tx__0__HSIOM)
    #define Debugging_RX_TX_HSIOM_PTR   ( (reg32 *) Debugging_rx_tx__0__HSIOM)
    
    #define Debugging_RX_TX_HSIOM_MASK      (Debugging_rx_tx__0__HSIOM_MASK)
    #define Debugging_RX_TX_HSIOM_POS       (Debugging_rx_tx__0__HSIOM_SHIFT)
    #define Debugging_RX_TX_HSIOM_SEL_GPIO  (Debugging_rx_tx__0__HSIOM_GPIO)
    #define Debugging_RX_TX_HSIOM_SEL_UART  (Debugging_rx_tx__0__HSIOM_UART)
#endif /* (Debugging_UART_RX_TX_PIN) */

#if (Debugging_UART_RTS_PIN)
    #define Debugging_RTS_HSIOM_REG      (*(reg32 *) Debugging_rts__0__HSIOM)
    #define Debugging_RTS_HSIOM_PTR      ( (reg32 *) Debugging_rts__0__HSIOM)
    
    #define Debugging_RTS_HSIOM_MASK     (Debugging_rts__0__HSIOM_MASK)
    #define Debugging_RTS_HSIOM_POS      (Debugging_rts__0__HSIOM_SHIFT)    
    #define Debugging_RTS_HSIOM_SEL_GPIO (Debugging_rts__0__HSIOM_GPIO)
    #define Debugging_RTS_HSIOM_SEL_UART (Debugging_rts__0__HSIOM_UART)    
#endif /* (Debugging_UART_RTS_PIN) */


/***************************************
*        Registers Constants
***************************************/

/* HSIOM switch values. */ 
#define Debugging_HSIOM_DEF_SEL      (0x00u)
#define Debugging_HSIOM_GPIO_SEL     (0x00u)
/* The HSIOM values provided below are valid only for Debugging_CY_SCBIP_V0 
* and Debugging_CY_SCBIP_V1. It is not recommended to use them for 
* Debugging_CY_SCBIP_V2. Use pin name specific HSIOM constants provided 
* above instead for any SCB IP block version.
*/
#define Debugging_HSIOM_UART_SEL     (0x09u)
#define Debugging_HSIOM_I2C_SEL      (0x0Eu)
#define Debugging_HSIOM_SPI_SEL      (0x0Fu)

/* Pins settings index. */
#define Debugging_RX_WAKE_SCL_MOSI_PIN_INDEX   (0u)
#define Debugging_RX_SCL_MOSI_PIN_INDEX       (0u)
#define Debugging_TX_SDA_MISO_PIN_INDEX       (1u)
#define Debugging_CTS_SCLK_PIN_INDEX       (2u)
#define Debugging_RTS_SS0_PIN_INDEX       (3u)
#define Debugging_SS1_PIN_INDEX                  (4u)
#define Debugging_SS2_PIN_INDEX                  (5u)
#define Debugging_SS3_PIN_INDEX                  (6u)

/* Pins settings mask. */
#define Debugging_RX_WAKE_SCL_MOSI_PIN_MASK ((uint32) 0x01u << Debugging_RX_WAKE_SCL_MOSI_PIN_INDEX)
#define Debugging_RX_SCL_MOSI_PIN_MASK     ((uint32) 0x01u << Debugging_RX_SCL_MOSI_PIN_INDEX)
#define Debugging_TX_SDA_MISO_PIN_MASK     ((uint32) 0x01u << Debugging_TX_SDA_MISO_PIN_INDEX)
#define Debugging_CTS_SCLK_PIN_MASK     ((uint32) 0x01u << Debugging_CTS_SCLK_PIN_INDEX)
#define Debugging_RTS_SS0_PIN_MASK     ((uint32) 0x01u << Debugging_RTS_SS0_PIN_INDEX)
#define Debugging_SS1_PIN_MASK                ((uint32) 0x01u << Debugging_SS1_PIN_INDEX)
#define Debugging_SS2_PIN_MASK                ((uint32) 0x01u << Debugging_SS2_PIN_INDEX)
#define Debugging_SS3_PIN_MASK                ((uint32) 0x01u << Debugging_SS3_PIN_INDEX)

/* Pin interrupt constants. */
#define Debugging_INTCFG_TYPE_MASK           (0x03u)
#define Debugging_INTCFG_TYPE_FALLING_EDGE   (0x02u)

/* Pin Drive Mode constants. */
#define Debugging_PIN_DM_ALG_HIZ  (0u)
#define Debugging_PIN_DM_DIG_HIZ  (1u)
#define Debugging_PIN_DM_OD_LO    (4u)
#define Debugging_PIN_DM_STRONG   (6u)


/***************************************
*          Macro Definitions
***************************************/

/* Return drive mode of the pin */
#define Debugging_DM_MASK    (0x7u)
#define Debugging_DM_SIZE    (3u)
#define Debugging_GET_P4_PIN_DM(reg, pos) \
    ( ((reg) & (uint32) ((uint32) Debugging_DM_MASK << (Debugging_DM_SIZE * (pos)))) >> \
                                                              (Debugging_DM_SIZE * (pos)) )

#if (Debugging_TX_SDA_MISO_PIN)
    #define Debugging_CHECK_TX_SDA_MISO_PIN_USED \
                (Debugging_PIN_DM_ALG_HIZ != \
                    Debugging_GET_P4_PIN_DM(Debugging_uart_tx_i2c_sda_spi_miso_PC, \
                                                   Debugging_uart_tx_i2c_sda_spi_miso_SHIFT))
#endif /* (Debugging_TX_SDA_MISO_PIN) */

#if (Debugging_RTS_SS0_PIN)
    #define Debugging_CHECK_RTS_SS0_PIN_USED \
                (Debugging_PIN_DM_ALG_HIZ != \
                    Debugging_GET_P4_PIN_DM(Debugging_uart_rts_spi_ss0_PC, \
                                                   Debugging_uart_rts_spi_ss0_SHIFT))
#endif /* (Debugging_RTS_SS0_PIN) */

/* Set bits-mask in register */
#define Debugging_SET_REGISTER_BITS(reg, mask, pos, mode) \
                    do                                           \
                    {                                            \
                        (reg) = (((reg) & ((uint32) ~(uint32) (mask))) | ((uint32) ((uint32) (mode) << (pos)))); \
                    }while(0)

/* Set bit in the register */
#define Debugging_SET_REGISTER_BIT(reg, mask, val) \
                    ((val) ? ((reg) |= (mask)) : ((reg) &= ((uint32) ~((uint32) (mask)))))

#define Debugging_SET_HSIOM_SEL(reg, mask, pos, sel) Debugging_SET_REGISTER_BITS(reg, mask, pos, sel)
#define Debugging_SET_INCFG_TYPE(reg, mask, pos, intType) \
                                                        Debugging_SET_REGISTER_BITS(reg, mask, pos, intType)
#define Debugging_SET_INP_DIS(reg, mask, val) Debugging_SET_REGISTER_BIT(reg, mask, val)

/* Debugging_SET_I2C_SCL_DR(val) - Sets I2C SCL DR register.
*  Debugging_SET_I2C_SCL_HSIOM_SEL(sel) - Sets I2C SCL HSIOM settings.
*/
/* SCB I2C: scl signal */
#if (Debugging_CY_SCBIP_V0)
#if (Debugging_I2C_PINS)
    #define Debugging_SET_I2C_SCL_DR(val) Debugging_scl_Write(val)

    #define Debugging_SET_I2C_SCL_HSIOM_SEL(sel) \
                          Debugging_SET_HSIOM_SEL(Debugging_SCL_HSIOM_REG,  \
                                                         Debugging_SCL_HSIOM_MASK, \
                                                         Debugging_SCL_HSIOM_POS,  \
                                                         (sel))
    #define Debugging_WAIT_SCL_SET_HIGH  (0u == Debugging_scl_Read())

/* Unconfigured SCB: scl signal */
#elif (Debugging_RX_WAKE_SCL_MOSI_PIN)
    #define Debugging_SET_I2C_SCL_DR(val) \
                            Debugging_uart_rx_wake_i2c_scl_spi_mosi_Write(val)

    #define Debugging_SET_I2C_SCL_HSIOM_SEL(sel) \
                    Debugging_SET_HSIOM_SEL(Debugging_RX_WAKE_SCL_MOSI_HSIOM_REG,  \
                                                   Debugging_RX_WAKE_SCL_MOSI_HSIOM_MASK, \
                                                   Debugging_RX_WAKE_SCL_MOSI_HSIOM_POS,  \
                                                   (sel))

    #define Debugging_WAIT_SCL_SET_HIGH  (0u == Debugging_uart_rx_wake_i2c_scl_spi_mosi_Read())

#elif (Debugging_RX_SCL_MOSI_PIN)
    #define Debugging_SET_I2C_SCL_DR(val) \
                            Debugging_uart_rx_i2c_scl_spi_mosi_Write(val)


    #define Debugging_SET_I2C_SCL_HSIOM_SEL(sel) \
                            Debugging_SET_HSIOM_SEL(Debugging_RX_SCL_MOSI_HSIOM_REG,  \
                                                           Debugging_RX_SCL_MOSI_HSIOM_MASK, \
                                                           Debugging_RX_SCL_MOSI_HSIOM_POS,  \
                                                           (sel))

    #define Debugging_WAIT_SCL_SET_HIGH  (0u == Debugging_uart_rx_i2c_scl_spi_mosi_Read())

#else
    #define Debugging_SET_I2C_SCL_DR(val)        do{ /* Does nothing */ }while(0)
    #define Debugging_SET_I2C_SCL_HSIOM_SEL(sel) do{ /* Does nothing */ }while(0)

    #define Debugging_WAIT_SCL_SET_HIGH  (0u)
#endif /* (Debugging_I2C_PINS) */

/* SCB I2C: sda signal */
#if (Debugging_I2C_PINS)
    #define Debugging_WAIT_SDA_SET_HIGH  (0u == Debugging_sda_Read())
/* Unconfigured SCB: sda signal */
#elif (Debugging_TX_SDA_MISO_PIN)
    #define Debugging_WAIT_SDA_SET_HIGH  (0u == Debugging_uart_tx_i2c_sda_spi_miso_Read())
#else
    #define Debugging_WAIT_SDA_SET_HIGH  (0u)
#endif /* (Debugging_MOSI_SCL_RX_PIN) */
#endif /* (Debugging_CY_SCBIP_V0) */

/* Clear UART wakeup source */
#if (Debugging_RX_SCL_MOSI_PIN)
    #define Debugging_CLEAR_UART_RX_WAKE_INTR        do{ /* Does nothing */ }while(0)
    
#elif (Debugging_RX_WAKE_SCL_MOSI_PIN)
    #define Debugging_CLEAR_UART_RX_WAKE_INTR \
            do{                                      \
                (void) Debugging_uart_rx_wake_i2c_scl_spi_mosi_ClearInterrupt(); \
            }while(0)

#elif(Debugging_UART_RX_WAKE_PIN)
    #define Debugging_CLEAR_UART_RX_WAKE_INTR \
            do{                                      \
                (void) Debugging_rx_wake_ClearInterrupt(); \
            }while(0)
#else
#endif /* (Debugging_RX_SCL_MOSI_PIN) */


/***************************************
* The following code is DEPRECATED and
* must not be used.
***************************************/

/* Unconfigured pins */
#define Debugging_REMOVE_MOSI_SCL_RX_WAKE_PIN    Debugging_REMOVE_RX_WAKE_SCL_MOSI_PIN
#define Debugging_REMOVE_MOSI_SCL_RX_PIN         Debugging_REMOVE_RX_SCL_MOSI_PIN
#define Debugging_REMOVE_MISO_SDA_TX_PIN         Debugging_REMOVE_TX_SDA_MISO_PIN
#ifndef Debugging_REMOVE_SCLK_PIN
#define Debugging_REMOVE_SCLK_PIN                Debugging_REMOVE_CTS_SCLK_PIN
#endif /* Debugging_REMOVE_SCLK_PIN */
#ifndef Debugging_REMOVE_SS0_PIN
#define Debugging_REMOVE_SS0_PIN                 Debugging_REMOVE_RTS_SS0_PIN
#endif /* Debugging_REMOVE_SS0_PIN */

/* Unconfigured pins */
#define Debugging_MOSI_SCL_RX_WAKE_PIN   Debugging_RX_WAKE_SCL_MOSI_PIN
#define Debugging_MOSI_SCL_RX_PIN        Debugging_RX_SCL_MOSI_PIN
#define Debugging_MISO_SDA_TX_PIN        Debugging_TX_SDA_MISO_PIN
#ifndef Debugging_SCLK_PIN
#define Debugging_SCLK_PIN               Debugging_CTS_SCLK_PIN
#endif /* Debugging_SCLK_PIN */
#ifndef Debugging_SS0_PIN
#define Debugging_SS0_PIN                Debugging_RTS_SS0_PIN
#endif /* Debugging_SS0_PIN */

#if (Debugging_MOSI_SCL_RX_WAKE_PIN)
    #define Debugging_MOSI_SCL_RX_WAKE_HSIOM_REG     Debugging_RX_WAKE_SCL_MOSI_HSIOM_REG
    #define Debugging_MOSI_SCL_RX_WAKE_HSIOM_PTR     Debugging_RX_WAKE_SCL_MOSI_HSIOM_REG
    #define Debugging_MOSI_SCL_RX_WAKE_HSIOM_MASK    Debugging_RX_WAKE_SCL_MOSI_HSIOM_REG
    #define Debugging_MOSI_SCL_RX_WAKE_HSIOM_POS     Debugging_RX_WAKE_SCL_MOSI_HSIOM_REG

    #define Debugging_MOSI_SCL_RX_WAKE_INTCFG_REG    Debugging_RX_WAKE_SCL_MOSI_HSIOM_REG
    #define Debugging_MOSI_SCL_RX_WAKE_INTCFG_PTR    Debugging_RX_WAKE_SCL_MOSI_HSIOM_REG

    #define Debugging_MOSI_SCL_RX_WAKE_INTCFG_TYPE_POS   Debugging_RX_WAKE_SCL_MOSI_HSIOM_REG
    #define Debugging_MOSI_SCL_RX_WAKE_INTCFG_TYPE_MASK  Debugging_RX_WAKE_SCL_MOSI_HSIOM_REG
#endif /* (Debugging_RX_WAKE_SCL_MOSI_PIN) */

#if (Debugging_MOSI_SCL_RX_PIN)
    #define Debugging_MOSI_SCL_RX_HSIOM_REG      Debugging_RX_SCL_MOSI_HSIOM_REG
    #define Debugging_MOSI_SCL_RX_HSIOM_PTR      Debugging_RX_SCL_MOSI_HSIOM_PTR
    #define Debugging_MOSI_SCL_RX_HSIOM_MASK     Debugging_RX_SCL_MOSI_HSIOM_MASK
    #define Debugging_MOSI_SCL_RX_HSIOM_POS      Debugging_RX_SCL_MOSI_HSIOM_POS
#endif /* (Debugging_MOSI_SCL_RX_PIN) */

#if (Debugging_MISO_SDA_TX_PIN)
    #define Debugging_MISO_SDA_TX_HSIOM_REG      Debugging_TX_SDA_MISO_HSIOM_REG
    #define Debugging_MISO_SDA_TX_HSIOM_PTR      Debugging_TX_SDA_MISO_HSIOM_REG
    #define Debugging_MISO_SDA_TX_HSIOM_MASK     Debugging_TX_SDA_MISO_HSIOM_REG
    #define Debugging_MISO_SDA_TX_HSIOM_POS      Debugging_TX_SDA_MISO_HSIOM_REG
#endif /* (Debugging_MISO_SDA_TX_PIN_PIN) */

#if (Debugging_SCLK_PIN)
    #ifndef Debugging_SCLK_HSIOM_REG
    #define Debugging_SCLK_HSIOM_REG     Debugging_CTS_SCLK_HSIOM_REG
    #define Debugging_SCLK_HSIOM_PTR     Debugging_CTS_SCLK_HSIOM_PTR
    #define Debugging_SCLK_HSIOM_MASK    Debugging_CTS_SCLK_HSIOM_MASK
    #define Debugging_SCLK_HSIOM_POS     Debugging_CTS_SCLK_HSIOM_POS
    #endif /* Debugging_SCLK_HSIOM_REG */
#endif /* (Debugging_SCLK_PIN) */

#if (Debugging_SS0_PIN)
    #ifndef Debugging_SS0_HSIOM_REG
    #define Debugging_SS0_HSIOM_REG      Debugging_RTS_SS0_HSIOM_REG
    #define Debugging_SS0_HSIOM_PTR      Debugging_RTS_SS0_HSIOM_PTR
    #define Debugging_SS0_HSIOM_MASK     Debugging_RTS_SS0_HSIOM_MASK
    #define Debugging_SS0_HSIOM_POS      Debugging_RTS_SS0_HSIOM_POS
    #endif /* Debugging_SS0_HSIOM_REG */
#endif /* (Debugging_SS0_PIN) */

#define Debugging_MOSI_SCL_RX_WAKE_PIN_INDEX Debugging_RX_WAKE_SCL_MOSI_PIN_INDEX
#define Debugging_MOSI_SCL_RX_PIN_INDEX      Debugging_RX_SCL_MOSI_PIN_INDEX
#define Debugging_MISO_SDA_TX_PIN_INDEX      Debugging_TX_SDA_MISO_PIN_INDEX
#ifndef Debugging_SCLK_PIN_INDEX
#define Debugging_SCLK_PIN_INDEX             Debugging_CTS_SCLK_PIN_INDEX
#endif /* Debugging_SCLK_PIN_INDEX */
#ifndef Debugging_SS0_PIN_INDEX
#define Debugging_SS0_PIN_INDEX              Debugging_RTS_SS0_PIN_INDEX
#endif /* Debugging_SS0_PIN_INDEX */

#define Debugging_MOSI_SCL_RX_WAKE_PIN_MASK Debugging_RX_WAKE_SCL_MOSI_PIN_MASK
#define Debugging_MOSI_SCL_RX_PIN_MASK      Debugging_RX_SCL_MOSI_PIN_MASK
#define Debugging_MISO_SDA_TX_PIN_MASK      Debugging_TX_SDA_MISO_PIN_MASK
#ifndef Debugging_SCLK_PIN_MASK
#define Debugging_SCLK_PIN_MASK             Debugging_CTS_SCLK_PIN_MASK
#endif /* Debugging_SCLK_PIN_MASK */
#ifndef Debugging_SS0_PIN_MASK
#define Debugging_SS0_PIN_MASK              Debugging_RTS_SS0_PIN_MASK
#endif /* Debugging_SS0_PIN_MASK */

#endif /* (CY_SCB_PINS_Debugging_H) */


/* [] END OF FILE */
