/***************************************************************************//**
* \file .h
* \version 4.0
*
* \brief
*  This private file provides constants and parameter values for the
*  SCB Component.
*  Please do not use this file or its content in your project.
*
* Note:
*
********************************************************************************
* \copyright
* Copyright 2013-2017, Cypress Semiconductor Corporation. All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_SCB_PVT_Debugging_H)
#define CY_SCB_PVT_Debugging_H

#include "Debugging.h"


/***************************************
*     Private Function Prototypes
***************************************/

/* APIs to service INTR_I2C_EC register */
#define Debugging_SetI2CExtClkInterruptMode(interruptMask) Debugging_WRITE_INTR_I2C_EC_MASK(interruptMask)
#define Debugging_ClearI2CExtClkInterruptSource(interruptMask) Debugging_CLEAR_INTR_I2C_EC(interruptMask)
#define Debugging_GetI2CExtClkInterruptSource()                (Debugging_INTR_I2C_EC_REG)
#define Debugging_GetI2CExtClkInterruptMode()                  (Debugging_INTR_I2C_EC_MASK_REG)
#define Debugging_GetI2CExtClkInterruptSourceMasked()          (Debugging_INTR_I2C_EC_MASKED_REG)

#if (!Debugging_CY_SCBIP_V1)
    /* APIs to service INTR_SPI_EC register */
    #define Debugging_SetSpiExtClkInterruptMode(interruptMask) \
                                                                Debugging_WRITE_INTR_SPI_EC_MASK(interruptMask)
    #define Debugging_ClearSpiExtClkInterruptSource(interruptMask) \
                                                                Debugging_CLEAR_INTR_SPI_EC(interruptMask)
    #define Debugging_GetExtSpiClkInterruptSource()                 (Debugging_INTR_SPI_EC_REG)
    #define Debugging_GetExtSpiClkInterruptMode()                   (Debugging_INTR_SPI_EC_MASK_REG)
    #define Debugging_GetExtSpiClkInterruptSourceMasked()           (Debugging_INTR_SPI_EC_MASKED_REG)
#endif /* (!Debugging_CY_SCBIP_V1) */

#if(Debugging_SCB_MODE_UNCONFIG_CONST_CFG)
    extern void Debugging_SetPins(uint32 mode, uint32 subMode, uint32 uartEnableMask);
#endif /* (Debugging_SCB_MODE_UNCONFIG_CONST_CFG) */


/***************************************
*     Vars with External Linkage
***************************************/

#if (Debugging_SCB_IRQ_INTERNAL)
#if !defined (CY_REMOVE_Debugging_CUSTOM_INTR_HANDLER)
    extern cyisraddress Debugging_customIntrHandler;
#endif /* !defined (CY_REMOVE_Debugging_CUSTOM_INTR_HANDLER) */
#endif /* (Debugging_SCB_IRQ_INTERNAL) */

extern Debugging_BACKUP_STRUCT Debugging_backup;

#if(Debugging_SCB_MODE_UNCONFIG_CONST_CFG)
    /* Common configuration variables */
    extern uint8 Debugging_scbMode;
    extern uint8 Debugging_scbEnableWake;
    extern uint8 Debugging_scbEnableIntr;

    /* I2C configuration variables */
    extern uint8 Debugging_mode;
    extern uint8 Debugging_acceptAddr;

    /* SPI/UART configuration variables */
    extern volatile uint8 * Debugging_rxBuffer;
    extern uint8   Debugging_rxDataBits;
    extern uint32  Debugging_rxBufferSize;

    extern volatile uint8 * Debugging_txBuffer;
    extern uint8   Debugging_txDataBits;
    extern uint32  Debugging_txBufferSize;

    /* EZI2C configuration variables */
    extern uint8 Debugging_numberOfAddr;
    extern uint8 Debugging_subAddrSize;
#endif /* (Debugging_SCB_MODE_UNCONFIG_CONST_CFG) */

#if (! (Debugging_SCB_MODE_I2C_CONST_CFG || \
        Debugging_SCB_MODE_EZI2C_CONST_CFG))
    extern uint16 Debugging_IntrTxMask;
#endif /* (! (Debugging_SCB_MODE_I2C_CONST_CFG || \
              Debugging_SCB_MODE_EZI2C_CONST_CFG)) */


/***************************************
*        Conditional Macro
****************************************/

#if(Debugging_SCB_MODE_UNCONFIG_CONST_CFG)
    /* Defines run time operation mode */
    #define Debugging_SCB_MODE_I2C_RUNTM_CFG     (Debugging_SCB_MODE_I2C      == Debugging_scbMode)
    #define Debugging_SCB_MODE_SPI_RUNTM_CFG     (Debugging_SCB_MODE_SPI      == Debugging_scbMode)
    #define Debugging_SCB_MODE_UART_RUNTM_CFG    (Debugging_SCB_MODE_UART     == Debugging_scbMode)
    #define Debugging_SCB_MODE_EZI2C_RUNTM_CFG   (Debugging_SCB_MODE_EZI2C    == Debugging_scbMode)
    #define Debugging_SCB_MODE_UNCONFIG_RUNTM_CFG \
                                                        (Debugging_SCB_MODE_UNCONFIG == Debugging_scbMode)

    /* Defines wakeup enable */
    #define Debugging_SCB_WAKE_ENABLE_CHECK       (0u != Debugging_scbEnableWake)
#endif /* (Debugging_SCB_MODE_UNCONFIG_CONST_CFG) */

/* Defines maximum number of SCB pins */
#if (!Debugging_CY_SCBIP_V1)
    #define Debugging_SCB_PINS_NUMBER    (7u)
#else
    #define Debugging_SCB_PINS_NUMBER    (2u)
#endif /* (!Debugging_CY_SCBIP_V1) */

#endif /* (CY_SCB_PVT_Debugging_H) */


/* [] END OF FILE */
