/***************************************************************************//**
* \file Debugging_SPI_UART_PVT.h
* \version 4.0
*
* \brief
*  This private file provides constants and parameter values for the
*  SCB Component in SPI and UART modes.
*  Please do not use this file or its content in your project.
*
* Note:
*
********************************************************************************
* \copyright
* Copyright 2013-2017, Cypress Semiconductor Corporation. All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_SCB_SPI_UART_PVT_Debugging_H)
#define CY_SCB_SPI_UART_PVT_Debugging_H

#include "Debugging_SPI_UART.h"


/***************************************
*     Internal Global Vars
***************************************/

#if (Debugging_INTERNAL_RX_SW_BUFFER_CONST)
    extern volatile uint32  Debugging_rxBufferHead;
    extern volatile uint32  Debugging_rxBufferTail;
    
    /**
    * \addtogroup group_globals
    * @{
    */
    
    /** Sets when internal software receive buffer overflow
     *  was occurred.
    */  
    extern volatile uint8   Debugging_rxBufferOverflow;
    /** @} globals */
#endif /* (Debugging_INTERNAL_RX_SW_BUFFER_CONST) */

#if (Debugging_INTERNAL_TX_SW_BUFFER_CONST)
    extern volatile uint32  Debugging_txBufferHead;
    extern volatile uint32  Debugging_txBufferTail;
#endif /* (Debugging_INTERNAL_TX_SW_BUFFER_CONST) */

#if (Debugging_INTERNAL_RX_SW_BUFFER)
    extern volatile uint8 Debugging_rxBufferInternal[Debugging_INTERNAL_RX_BUFFER_SIZE];
#endif /* (Debugging_INTERNAL_RX_SW_BUFFER) */

#if (Debugging_INTERNAL_TX_SW_BUFFER)
    extern volatile uint8 Debugging_txBufferInternal[Debugging_TX_BUFFER_SIZE];
#endif /* (Debugging_INTERNAL_TX_SW_BUFFER) */


/***************************************
*     Private Function Prototypes
***************************************/

void Debugging_SpiPostEnable(void);
void Debugging_SpiStop(void);

#if (Debugging_SCB_MODE_SPI_CONST_CFG)
    void Debugging_SpiInit(void);
#endif /* (Debugging_SCB_MODE_SPI_CONST_CFG) */

#if (Debugging_SPI_WAKE_ENABLE_CONST)
    void Debugging_SpiSaveConfig(void);
    void Debugging_SpiRestoreConfig(void);
#endif /* (Debugging_SPI_WAKE_ENABLE_CONST) */

void Debugging_UartPostEnable(void);
void Debugging_UartStop(void);

#if (Debugging_SCB_MODE_UART_CONST_CFG)
    void Debugging_UartInit(void);
#endif /* (Debugging_SCB_MODE_UART_CONST_CFG) */

#if (Debugging_UART_WAKE_ENABLE_CONST)
    void Debugging_UartSaveConfig(void);
    void Debugging_UartRestoreConfig(void);
#endif /* (Debugging_UART_WAKE_ENABLE_CONST) */


/***************************************
*         UART API Constants
***************************************/

/* UART RX and TX position to be used in Debugging_SetPins() */
#define Debugging_UART_RX_PIN_ENABLE    (Debugging_UART_RX)
#define Debugging_UART_TX_PIN_ENABLE    (Debugging_UART_TX)

/* UART RTS and CTS position to be used in  Debugging_SetPins() */
#define Debugging_UART_RTS_PIN_ENABLE    (0x10u)
#define Debugging_UART_CTS_PIN_ENABLE    (0x20u)


/***************************************
* The following code is DEPRECATED and
* must not be used.
***************************************/

/* Interrupt processing */
#define Debugging_SpiUartEnableIntRx(intSourceMask)  Debugging_SetRxInterruptMode(intSourceMask)
#define Debugging_SpiUartEnableIntTx(intSourceMask)  Debugging_SetTxInterruptMode(intSourceMask)
uint32  Debugging_SpiUartDisableIntRx(void);
uint32  Debugging_SpiUartDisableIntTx(void);


#endif /* (CY_SCB_SPI_UART_PVT_Debugging_H) */


/* [] END OF FILE */
